@@ -1,7 +1,7 @@
 package Catmandu::Importer::MAB2;
 
 #ABSTRACT: Package that imports MAB2 data
-our $VERSION = '0.06'; #VERSION
+our $VERSION = '0.08'; #VERSION
 
 use Catmandu::Sane;
 use Moo;
@@ -49,7 +49,7 @@ sub generator {
         return $self->mab_generator;
     }
     else {
-        die "need MAB2 RAW or XML data";
+        die "need MAB2 Disk, RAW or XML data";
     }
 }
 
@@ -60,13 +60,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Catmandu::Importer::MAB2 - Package that imports MAB2 data
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -124,13 +126,13 @@ C<fh>, etc.) the importer can be configured with the following parameters:
 
 Describes the MAB2 syntax variant. Supported values (case ignored) include the
 default value C<xml> for MABxml, C<disk> for human-readable MAB2 serialization 
-and C<plus> or C<raw> for normalized MAB2.
+("Diskettenformat") or C<raw> for data-exchange MAB2 serialization ("Bandformat").
 
 =back
 
 =head1 AUTHOR
 
-Johann Rolschewski <rolschewski@gmail.com>
+Johann Rolschewski <jorol@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
