@@ -1,7 +1,8 @@
 package Catmandu::MAB2;
 
 #ABSTRACT: Catmandu modules for working with MAB2 data.
-our $VERSION = '0.07'; #VERSION
+
+our $VERSION = 0.08;
 
 use strict;
 use warnings;
@@ -67,7 +68,7 @@ Parser and writer for MAB2 data.
 
 =head1 AUTHOR
 
-Johann Rolschewski <rolschewski@gmail.com>
+Johann Rolschewski <jorol@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
