@@ -1,7 +1,7 @@
 package MAB2::Parser::XML;
 
 #ABSTRACT: MAB2 XML parser
-our $VERSION = '0.07'; #VERSION
+our $VERSION = '0.08'; #VERSION
 
 use strict;
 use warnings;
@@ -160,7 +160,7 @@ L<Catmandu::Importer::MAB2>.
 
 =head1 AUTHOR
 
-Johann Rolschewski <rolschewski@gmail.com>
+Johann Rolschewski <jorol@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
