@@ -1,7 +1,7 @@
 package MAB2::Writer::Handle;
 
 #ABSTRACT: Utility class for common MAB2::Writer arguments and methods.
-our $VERSION = '0.06'; #VERSION
+our $VERSION = '0.08'; #VERSION
 
 use strict;
 use Moo::Role;
@@ -67,13 +67,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MAB2::Writer::Handle - Utility class for common MAB2::Writer arguments and methods.
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 Arguments
 
@@ -109,7 +111,7 @@ Write record to filehandle.
 
 =head1 AUTHOR
 
-Johann Rolschewski <rolschewski@gmail.com>
+Johann Rolschewski <jorol@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
